@@ -5,7 +5,9 @@ import math
 import expenvelope  # type: ignore
 
 import mutwo_third_party
+
 from mutwo import converters
+from mutwo.converters.symmetrical import loudness_constants
 from mutwo.utilities import constants
 
 
@@ -15,34 +17,26 @@ __all__ = ("LoudnessToAmplitudeConverter",)
 class LoudnessToAmplitudeConverter(converters.abc.Converter):
     """Make an approximation of the needed amplitude for a perceived Loudness.
 
-    :param perceived_loudness_in_sone: The subjectively perceived loudness that
-        the resulting signal shall have (in the unit `Sone`).
     :param loudspeaker_frequency_response: Optionally the frequency response
         of the used loudspeaker can be added for balancing out uneven curves in
         the loudspeakers frequency response. The frequency response is defined
         with an ``expenvelope.Envelope`` object.
+    :type loudspeaker_frequency_response: expenvelope.Envelope
     :param interpolation_order: The interpolation order of the equal loudness
         contour interpolation.
+    :type interpolation_order: int
 
     The converter works best with pure sine waves.
     """
 
-    # roughly the sound of a mosquito flying 3 m away
-    # (see https://en.wikipedia.org/wiki/Sound_pressure)
-    _auditory_threshold_at_1khz = 0.00002
-
     def __init__(
         self,
-        perceived_loudness_in_sone: constants.Real,
         loudspeaker_frequency_response: expenvelope.Envelope = expenvelope.Envelope.from_points(
             (0, 80), (2000, 80)
         ),
         interpolation_order: int = 4,
     ):
-        perceived_loudness_in_phon = self._sone_to_phon(perceived_loudness_in_sone)
-        self._equal_loudness_contour_interpolation = mutwo_third_party.pydsm.pydsm.iso226.iso226_spl_itpl(  # type: ignore
-            perceived_loudness_in_phon, interpolation_order
-        )
+        self._interpolation_order = interpolation_order
         self._loudspeaker_frequency_response = loudspeaker_frequency_response
         self._loudspeaker_frequency_response_average = (
             loudspeaker_frequency_response.average_level()
@@ -74,9 +68,14 @@ class LoudnessToAmplitudeConverter(converters.abc.Converter):
     #               public methods for interaction with the user             #
     # ###################################################################### #
 
-    def convert(self, frequency: constants.Real) -> constants.Real:
+    def convert(
+        self, perceived_loudness_in_sone: constants.Real, frequency: constants.Real
+    ) -> constants.Real:
         """Calculates the needed amplitude to reach a particular loudness for the entered frequency.
 
+        :param perceived_loudness_in_sone: The subjectively perceived loudness that
+            the resulting signal shall have (in the unit `Sone`).
+        :type perceived_loudness_in_sone: constants.Real
         :param frequency: A frequency in Hertz for which the necessary amplitude
             shall be calculated.
         :return: Return the amplitude for a sine tone to reach the converters
@@ -92,16 +91,21 @@ class LoudnessToAmplitudeConverter(converters.abc.Converter):
         0.15497924558613232
         """
 
+        perceived_loudness_in_phon = self._sone_to_phon(perceived_loudness_in_sone)
+        equal_loudness_contour_interpolation = mutwo_third_party.pydsm.pydsm.iso226.iso226_spl_itpl(  # type: ignore
+            perceived_loudness_in_phon, self._interpolation_order
+        )
+
         # (1) calculates necessary sound pressure level depending on the frequency
         #     and loudness (to get the same loudness over all frequencies)
         sound_pressure_level_for_perceived_loudness_based_on_frequency = float(
-            self._equal_loudness_contour_interpolation(frequency)
+            equal_loudness_contour_interpolation(frequency)
         )
         # (2) figure out the produced soundpressure of the loudspeaker depending
         #     on the frequency (for balancing uneven frequency responses of
         #     loudspeakers)
-        produced_soundpressure_for_1_watt_1_meter_depending_on_loudspeaker = self._loudspeaker_frequency_response.value_at(
-            frequency
+        produced_soundpressure_for_1_watt_1_meter_depending_on_loudspeaker = (
+            self._loudspeaker_frequency_response.value_at(frequency)
         )
         difference_to_average = (
             self._loudspeaker_frequency_response_average
@@ -113,6 +117,6 @@ class LoudnessToAmplitudeConverter(converters.abc.Converter):
         )
         amplitude_ratio = self._decibel_to_amplitude_ratio(
             sound_pressure_level_for_pereived_loudness_based_on_speaker,
-            self._auditory_threshold_at_1khz,
+            loudness_constants.AUDITORY_THRESHOLD_AT_1KHZ,
         )
         return amplitude_ratio
