@@ -100,7 +100,7 @@ class TempoConverter(converters.abc.EventConverter):
 
     :param tempo_envelope: The tempo curve that shall be applied on the
         mutwo events. This is expected to be a :class:`expenvelope.Envelope`
-        which levels arefilled with numbers that will be interpreted as BPM
+        which levels are filled with numbers that will be interpreted as BPM
         [beats per minute]) or with :class:`mutwo.parameters.tempos.TempoPoint`
         objects.
 
@@ -133,15 +133,15 @@ class TempoConverter(converters.abc.EventConverter):
     ) -> expenvelope.Envelope:
         """Convert bpm / TempoPoint based env to beat-length-in-seconds env."""
 
-        levels: list[float] = []
+        level_list: list[float] = []
         for tempo_point in tempo_envelope.levels:
             beat_length_in_seconds = TempoConverter._tempo_point_converter.convert(
                 tempo_point
             )
-            levels.append(beat_length_in_seconds)
+            level_list.append(beat_length_in_seconds)
 
         return expenvelope.Envelope.from_levels_and_durations(
-            levels, tempo_envelope.durations, tempo_envelope.curve_shapes
+            level_list, tempo_envelope.durations, tempo_envelope.curve_shapes
         )
 
     # ###################################################################### #
